==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/DiskEncryptionInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.DiskEncryptionInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Recovery disk encryption info (BEK and KEK).
 * @property diskEncryptionKeyInfo The recovery KeyVault reference for secret.
 * @property keyEncryptionKeyInfo The recovery KeyVault reference for key.
 */
public data class DiskEncryptionInfoArgs(
    public val diskEncryptionKeyInfo: Output<DiskEncryptionKeyInfoArgs>? = null,
    public val keyEncryptionKeyInfo: Output<KeyEncryptionKeyInfoArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.DiskEncryptionInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.recoveryservices.inputs.DiskEncryptionInfoArgs =
        com.pulumi.azurenative.recoveryservices.inputs.DiskEncryptionInfoArgs.builder()
            .diskEncryptionKeyInfo(
                diskEncryptionKeyInfo?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .keyEncryptionKeyInfo(
                keyEncryptionKeyInfo?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [DiskEncryptionInfoArgs].
 */
@PulumiTagMarker
public class DiskEncryptionInfoArgsBuilder internal constructor() {
    private var diskEncryptionKeyInfo: Output<DiskEncryptionKeyInfoArgs>? = null

    private var keyEncryptionKeyInfo: Output<KeyEncryptionKeyInfoArgs>? = null

    /**
     * @param value The recovery KeyVault reference for secret.
     */
    @JvmName("qjsxmlrmsoattuqc")
    public suspend fun diskEncryptionKeyInfo(`value`: Output<DiskEncryptionKeyInfoArgs>) {
        this.diskEncryptionKeyInfo = value
    }

    /**
     * @param value The recovery KeyVault reference for key.
     */
    @JvmName("oukuebkcjmmvirlx")
    public suspend fun keyEncryptionKeyInfo(`value`: Output<KeyEncryptionKeyInfoArgs>) {
        this.keyEncryptionKeyInfo = value
    }

    /**
     * @param value The recovery KeyVault reference for secret.
     */
    @JvmName("eebtfsoeoracwmpb")
    public suspend fun diskEncryptionKeyInfo(`value`: DiskEncryptionKeyInfoArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskEncryptionKeyInfo = mapped
    }

    /**
     * @param argument The recovery KeyVault reference for secret.
     */
    @JvmName("dniqqhohjhsbfpqx")
    public suspend
    fun diskEncryptionKeyInfo(argument: suspend DiskEncryptionKeyInfoArgsBuilder.() -> Unit) {
        val toBeMapped = DiskEncryptionKeyInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.diskEncryptionKeyInfo = mapped
    }

    /**
     * @param value The recovery KeyVault reference for key.
     */
    @JvmName("lyimjyrinjywerxv")
    public suspend fun keyEncryptionKeyInfo(`value`: KeyEncryptionKeyInfoArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keyEncryptionKeyInfo = mapped
    }

    /**
     * @param argument The recovery KeyVault reference for key.
     */
    @JvmName("xmthxkrdyyekwvtj")
    public suspend
    fun keyEncryptionKeyInfo(argument: suspend KeyEncryptionKeyInfoArgsBuilder.() -> Unit) {
        val toBeMapped = KeyEncryptionKeyInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.keyEncryptionKeyInfo = mapped
    }

    internal fun build(): DiskEncryptionInfoArgs = DiskEncryptionInfoArgs(
        diskEncryptionKeyInfo = diskEncryptionKeyInfo,
        keyEncryptionKeyInfo = keyEncryptionKeyInfo,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/DiskEncryptionInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.DiskEncryptionInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Recovery disk encryption info (BEK and KEK).
 * @property diskEncryptionKeyInfo The recovery KeyVault reference for secret.
 * @property keyEncryptionKeyInfo The recovery KeyVault reference for key.
 */
public data class DiskEncryptionInfoArgs(
    public val diskEncryptionKeyInfo: Output<DiskEncryptionKeyInfoArgs>? = null,
    public val keyEncryptionKeyInfo: Output<KeyEncryptionKeyInfoArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.DiskEncryptionInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.recoveryservices.inputs.DiskEncryptionInfoArgs =
        com.pulumi.azurenative.recoveryservices.inputs.DiskEncryptionInfoArgs.builder()
            .diskEncryptionKeyInfo(
                diskEncryptionKeyInfo?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .keyEncryptionKeyInfo(
                keyEncryptionKeyInfo?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [DiskEncryptionInfoArgs].
 */
@PulumiTagMarker
public class DiskEncryptionInfoArgsBuilder internal constructor() {
    private var diskEncryptionKeyInfo: Output<DiskEncryptionKeyInfoArgs>? = null

    private var keyEncryptionKeyInfo: Output<KeyEncryptionKeyInfoArgs>? = null

    /**
     * @param value The recovery KeyVault reference for secret.
     */
    @JvmName("xtwlsudfkpsrcawy")
    public suspend fun diskEncryptionKeyInfo(`value`: Output<DiskEncryptionKeyInfoArgs>) {
        this.diskEncryptionKeyInfo = value
    }

    /**
     * @param value The recovery KeyVault reference for key.
     */
    @JvmName("ggwnbbcnlryhxwqx")
    public suspend fun keyEncryptionKeyInfo(`value`: Output<KeyEncryptionKeyInfoArgs>) {
        this.keyEncryptionKeyInfo = value
    }

    /**
     * @param value The recovery KeyVault reference for secret.
     */
    @JvmName("mgosdbdhftgqraol")
    public suspend fun diskEncryptionKeyInfo(`value`: DiskEncryptionKeyInfoArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskEncryptionKeyInfo = mapped
    }

    /**
     * @param argument The recovery KeyVault reference for secret.
     */
    @JvmName("rmetrmabjymgtujy")
    public suspend
    fun diskEncryptionKeyInfo(argument: suspend DiskEncryptionKeyInfoArgsBuilder.() -> Unit) {
        val toBeMapped = DiskEncryptionKeyInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.diskEncryptionKeyInfo = mapped
    }

    /**
     * @param value The recovery KeyVault reference for key.
     */
    @JvmName("pslvqjwcesoixxjy")
    public suspend fun keyEncryptionKeyInfo(`value`: KeyEncryptionKeyInfoArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keyEncryptionKeyInfo = mapped
    }

    /**
     * @param argument The recovery KeyVault reference for key.
     */
    @JvmName("rvyvfconyanwernm")
    public suspend
    fun keyEncryptionKeyInfo(argument: suspend KeyEncryptionKeyInfoArgsBuilder.() -> Unit) {
        val toBeMapped = KeyEncryptionKeyInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.keyEncryptionKeyInfo = mapped
    }

    internal fun build(): DiskEncryptionInfoArgs = DiskEncryptionInfoArgs(
        diskEncryptionKeyInfo = diskEncryptionKeyInfo,
        keyEncryptionKeyInfo = keyEncryptionKeyInfo,
    )
}
